@@ -228,7 +228,8 @@ def main():
     args = parser.parse_args()
 
     if args.usage:
-        parser.exit(message=DESCRIPTION+FULL_DESCRIPTION)
+        print(DESCRIPTION+FULL_DESCRIPTION)
+        sys.exit()
 
     if len(args.time) == 2 and args.time_window:
         parser.error("Time-window argument incompatible with speicyfing two times.")
