@@ -20,13 +20,14 @@ from . import nds
 logger = logging.getLogger('DATA ')
 
 
-_ctype_map = {
-    'online': 'raw',
-    'raw': 'raw',
-    'reduced': 'raw',
-    's-trend': 'sec',
-    'm-trend': 'min',
-}
+def _ctype_map(ctype):
+    return {
+        'online': 'raw',
+        'raw': 'raw',
+        'reduced': 'raw',
+        's-trend': 'sec',
+        'm-trend': 'min',
+    }.get(ctype, 'raw')
 
 
 class DataBuffer(object):
@@ -43,14 +44,14 @@ class DataBuffer(object):
         'channel', 'ctype', 'sample_rate',
         'trend', 'unit',
         'data', 'size', 'gps_start', 'tarray',
-        'max_samples',
+        'max_samples', 'lookback',
         'last_append_len',
     ]
 
     def __init__(self, buf):
         """initialize with NDS-like Buffer object"""
         self.channel, mod, self.ctype = nds.parse_channel(buf.channel)
-        self.trend = _ctype_map[self.ctype]
+        self.trend = _ctype_map(self.ctype)
         # HACK: fix m-trend sample rate.  The rate returned from NDS
         # is not accurate, seemingly subject to round-off error:
         # https://git.ligo.org/nds/nds2-distributed-server/issues/1
@@ -68,6 +69,7 @@ class DataBuffer(object):
         self.update_tarray()
         #self.max_samples = int(const.DATA_LOOKBACK_LIMIT_BYTES / buf.channel.DataTypeSize())
         self.max_samples = int(const.TREND_MAX_SECONDS[self.trend] * self.sample_rate)
+        self.lookback = 2
         self.last_append_len = 0
 
     def __repr__(self):
@@ -152,7 +154,7 @@ class DataBuffer(object):
         assert buf.channel == self.channel
         assert buf.sample_rate == self.sample_rate, "append buffer sample rate {} does not match {}".format(buf.sample_rate, self.sample_rate)
         assert buf.gps_start == self.gps_end, "append buffer start {} does not equal end {}".format(buf.gps_start, self.gps_end)
-        lbs = self.max_samples
+        lbs = min(int(self.lookback * self.sample_rate), self.max_samples)
         for mod, data in self.data.items():
             self.data[mod] = np.append(data, buf.data[mod])[-lbs:]
         self.gps_start = max(
@@ -241,6 +243,10 @@ class DataBufferDict(object):
         for chan, buf in bufs.items():
             self.buffers[chan].append(buf)
 
+    def set_lookback(self, lookback):
+        for buf in self.values():
+            buf.lookback = lookback
+
 
 class DataStore(QtCore.QObject):
     # signals
@@ -270,12 +276,12 @@ class DataStore(QtCore.QObject):
         # many channel referneces as needed can be added, while only
         # storing one set of channel data
         self._channels = collections.Counter()
-        self.lookback = 2
         self.last_trend = None
         self.last_start_end = None
         self.restart_requested = False
         self.threads = {}
         self.reset()
+        self.set_lookback(2)
 
     def __getitem__(self, mod):
         return self.db[mod]
@@ -287,6 +293,12 @@ class DataStore(QtCore.QObject):
             return thread.trend
         return False
 
+    def set_lookback(self, lookback):
+        self.lookback = lookback
+        for bd in self.db.values():
+            if bd:
+                bd.set_lookback(lookback)
+
     ##########
 
     def _emit_data(self, trend, online=False):
@@ -350,7 +362,7 @@ class DataStore(QtCore.QObject):
             trend = 'sec'
         logger.debug('START ONLINE')
         self.last_trend = trend
-        self.lookback = lookback
+        self.set_lookback(lookback)
         self.reset()
         self.signal_data.connect(self._online_backfill)
         self.remote_cmd(trend, 'online', None)
@@ -424,6 +436,8 @@ class DataStore(QtCore.QObject):
             ))
             return
 
+        now = gpsnow()
+
         if self.online:
             if trend == 'min':
                 # no support for min trends.  the iteration time is
@@ -437,13 +451,12 @@ class DataStore(QtCore.QObject):
                 self.online_restart()
                 return
             # note we continue if online and trend is not changing
+            self.set_lookback(abs(now - start))
 
         # expand range to ints
         rstart = int(start)
         rend = int(np.ceil(end))
 
-        now = gpsnow()
-
         if rstart > now:
             # self.signal_data_retrieve_done.emit("Requested start time in the future.")
             return
@@ -458,7 +471,7 @@ class DataStore(QtCore.QObject):
         # seconds of online data, which should be fixed in the
         # servers.
         if not self.online:
-            rend = min(rend, now - 10)
+            rend = min(rend, now - 1)
 
         if rend <= rstart:
             return
@@ -553,6 +566,7 @@ class DataStore(QtCore.QObject):
             self.signal_data_retrieve_start.emit(msg)
         # FIXME: should the NDS object just return this directly?
         dbd = DataBufferDict(buffers)
+        dbd.set_lookback(self.lookback)
         if not self.db.get(trend):
             self.db[trend] = dbd
         elif cmd == 'online':
